@@ -1,19 +1,19 @@
-# Check chosen criterion
-# 
-# Checks if the criterion is viable or matches it to the list of implemented 
-# criterions.
-# 
-# @param input_criterion \code{character} string, criterion from input.
-# @param criterion_names list of implemented criterions, always in lowercase.
-# @export
-# @return a list of three: 
-# \itemize{
-# \item{criterion name,}
-# \item{its function,}
-# \item{nice name for outputs.}
-# }
-# @seealso
-# Calculate the value of criterion: \code{\link{calc_criterion}}.
+#' Check chosen criterion
+#' 
+#' Checks if the criterion is viable or matches it to the list of implemented
+#' criterions.
+#' 
+#' @param input_criterion \code{character} string, criterion from input.
+#' @param criterion_names list of implemented criterions, always in lowercase.
+#' @export
+#' @return a list of three:
+#' \itemize{
+#' \item{criterion name,}
+#' \item{its function,}
+#' \item{nice name for outputs.}
+#' }
+#' @seealso
+#' Calculate the value of criterion: \code{\link{calc_criterion}}.
 check_criterion <- function(input_criterion, criterion_names = c("ig", "kl", "cs")) {
   # think twice about grep
   valid_name <- criterion_names[grepl(tolower(input_criterion), criterion_names)]
@@ -63,10 +63,10 @@ check_criterion <- function(input_criterion, criterion_names = c("ig", "kl", "cs
 #' # Kullback-Leibler divergence
 #' calc_criterion(tar, feats, calc_kl)
 calc_criterion <- function(target, features, criterion_function) {
-  tar_bit <- as.bit(target)
+  tar <- target
   l_tar <- length(target)
   pos_tar <- sum(target)
   
   apply(features, 2, function(single_feature) 
-    criterion_function(single_feature, tar_bit, l_tar, pos_tar))
+    criterion_function(single_feature, tar, l_tar, pos_tar))
 }
\ No newline at end of file
